module risclab1(
  // Clock Input (50 MHz)
  input  CLOCK_50,
  //  Push Buttons
  input  [3:0]  KEY,
  //  DPDT Switches 
  input  [17:0]  SW,
  //  7-SEG Displays
  output  [6:0]  HEX0, HEX1, HEX2, HEX3, HEX4, HEX5, HEX6, HEX7,
  //  LEDs
  output  [8:0]  LEDG,  //  LED Green[8:0]
  output  [17:0]  LEDR,  //  LED Red[17:0]
  //  GPIO Connections
  inout  [35:0]  GPIO_0, GPIO_1
);

//  set all inout ports to tri-state
assign  GPIO_0    =  36'hzzzzzzzzz;
assign  GPIO_1    =  36'hzzzzzzzzz;

wire [6:0] myclock;
wire reset_n  = KEY[0];

// Setup clock divider
clock_divider cdiv(CLOCK_50,reset_n,myclock);

assign LEDG[8:1] = 8'h00;
assign LEDG[0] = active;

// Connect dip switches to red LEDS
assign LEDR[17:0] = SW[17:0];


// map to 7-segment displays

wire [3:0] rx;
assign rx = {1'b0, ra[2:0]};

hex_7seg_blanking dsp4(rx,HEX4,SW[3]);


wire [15:0] dx;

hex_7seg_blanking dsp0(dx[3:0],HEX0,1'b0);
hex_7seg_blanking dsp1(dx[7:4],HEX1,1'b0);
hex_7seg_blanking dsp2(dx[11:8],HEX2,1'b0);
hex_7seg_blanking dsp3(dx[15:12],HEX3,1'b0);

wire [6:0] blank = ~7'h00;

assign HEX5 = blank;
//assign HEX6 = blank;
assign HEX7 = blank;
hex_7seg_blanking dsp6({2'h0,state},HEX6,~active);

wire [15:0] qa,qd;
wire [2:0] ra,rd;
assign ra = active? rd: SW[2:0];
assign dx = SW[3]? ncycles: (active? qd: qa);
wire we;

regfile u1(
	.clk(CLOCK_50),
	.ra(ra),
	.qa(qa),
	.rd(rd),
	.we(we),
	.qd(qd)
);

wire clk = (SW[17]? myclock[0]: CLOCK_50);

wire active;
wire [15:0] ncycles;
wire [1:0] state;


risc_cpu cpu0(
	.clk(clk),
	.reset_n(reset_n),
	.rd(rd),
	.qd(qd),
	.rwe(we),
	.cpu_active(active),
	.cpu_state(state),
	.ncycles(ncycles)
);


endmodule